# only if load external data
library(sf)
library(maptools)
library(raster)
library(rgeos)
library(geosphere)
library(rgdal)
library(spatstat)
library(ncdf4)

s  <- st_read("/home/mlanger/Dokumente/PermaRisk/Figures/animations_2020/PerProb_ConDis_glob_buffer.shp")
s_p = st_transform(s, CRS("+init=epsg:3575"))
ma  <- as.owin(s_p)
ma_perma <- ma

s  <- st_read("/home/mlanger/Dokumente/PermaRisk/Figures/animations_2020/R/Alaska_4326_cut_border.shp")
s_p = st_transform(s, CRS("+init=epsg:3575"))
ma  <- as.owin(s_p)
ma_alaska <- ma

s  <- st_read("/home/mlanger/Dokumente/PermaRisk/Figures/animations_2020/PerProb_ConDis_Alaska_buffer.shp")
s_p = st_transform(s, CRS("+init=epsg:3575"))
ma  <- as.owin(s_p)
ma_perma_alaska <- ma

# Load a contamination.shp point feature shapefile
s  <- st_read("/home/mlanger/Dokumente/PermaRisk/Figures/animations_2020/ContamSites_Indus_only.shp")
s_p = st_transform(s, 3575)
contamination  <- as.ppp(s_p)
marks(contamination)  <- NULL
contamination_alaska <- contamination
Window(contamination_alaska) <- ma_alaska

s  <- st_read("/home/mlanger/Dokumente/PermaRisk/Figures/animations_2020/ContamSites_Indus_only_perma.shp")
s_p = st_transform(s, 3575)
contamination  <- as.ppp(s_p)
marks(contamination)  <- NULL
contamination_perma_alaska <- contamination
Window(contamination_perma_alaska) <- ma_perma_alaska

# Load a industry.shp point feature shapefile
s  <- st_read("/home/mlanger/Dokumente/PermaRisk/Figures/animations_2020/bigindustry_ipcc_points_final4326_alaska.shp")
s_p = st_transform(s, 3575)
industry  <- as.ppp(s_p)
marks(industry) <- NULL
industry_alaska <- industry
Window(industry_alaska) <- ma_alaska

# Load a industry.shp point feature shapefile
s  <- st_read("/home/mlanger/Dokumente/PermaRisk/Figures/animations_2020/bigindustry_ipcc_points_final4326_perma.shp")
s_p = st_transform(s, 3575)
industry_perma  <- as.ppp(s_p)
marks(industry_perma) <- NULL
industry_perma <- industry_perma 
industry_perma_alaska <- industry_perma 
Window(industry_perma) <- ma_perma
Window(industry_perma_alaska) <- ma_perma_alaska

plot(contamination_alaska, main=NULL, cols=rgb(0,0,0,.2), pch=20)
plot(industry_alaska, main=NULL, cols=rgb(1,0,0,.2), pch=20, add = TRUE)

plot(industry_perma_alaska, main=NULL, cols=rgb(1,0,0,.2), pch=20)
plot(contamination_perma_alaska, main=NULL, cols=rgb(0,0,0,.2), pch=20, add = TRUE)
#-------------------------------------------------------------------------------
#scale everything from meter to km
ma_alaska.km <-  rescale(ma_alaska, 1000, "km") 
ma_perma.km <-  rescale(ma_perma, 1000, "km") 
ma_perma_alaska.km <-  rescale(ma_perma_alaska, 1000, "km") 

contamination_alaska.km <- rescale(contamination_alaska, 1000, "km")
contamination_perma_alaska.km <- rescale(contamination_perma_alaska, 1000, "km")

industry_perma.km <- rescale(industry_perma, 1000, "km")
industry_alaska.km <- rescale(industry_alaska, 1000, "km")
industry_perma_alaska.km <- rescale(industry_perma_alaska, 1000, "km")

# build kernel density raster from points with 50km band width (sigma =50)
band_width <- 50
industry_perma.dens.km <- density(industry_perma.km, sigma=band_width) # Using a specified bandwidth an 10km resolution
industry_perma_alaska.dens.km <- density(industry_perma_alaska.km, sigma=band_width)
industry_alaska.dens.km <- density(industry_alaska.km, sigma=band_width) 

industry_perma.dist.km <- distmap(industry_perma.km)
industry_perma_alaska.dist.km <- distmap(industry_perma_alaska.km)
industry_alaska.dist.km <- distmap(industry_alaska.km)

industry_perma_alaska.dist_gauss.km <- exp(- 0.5*industry_perma_alaska.dist.km^2/band_width^2)
industry_perma.dist_gauss.km <- exp(- 0.5*industry_perma.dist.km^2/band_width^2)
industry_alaska.dist_gauss.km <- exp(- 0.5*industry_alaska.dist.km^2/band_width^2)

hist(industry_perma_alaska.dens.km, main=NULL, las=1) #histogram of the industry raster data
industry_perma_alaska.dens.lg.km <- log(industry_perma_alaska.dens.km) #transform skewed industry distribution to log distribution
industry_perma.dens.lg.km <- log(industry_perma.dens.km) #transform skewed industry distribution to log distribution
industry_alaska.dens.lg.km <- log(industry_alaska.dens.km) #transform skewed industry distribution to log distribution
hist(industry_perma.dens.lg.km, main=NULL, las=1) # new histogram

industry_perma.dens.lg.km[industry_perma.dens.lg.km=="-Inf"]=NaN
industry_perma_alaska.dens.lg.km[industry_perma_alaska.dens.lg.km=="-Inf"]=NaN
industry_alaska.dens.lg.km[industry_alaska.dens.lg.km=="-Inf"]=NaN

#-------------------------------------------------------------------------------
#A point process intensity is estimated following the raster density map as covariate.
# Compute rho using the ratio method
rho_perma_alaska <- rhohat(contamination_perma_alaska.km, industry_perma_alaska.dens.lg.km,  method="ratio")
rho_alaska <- rhohat(contamination_alaska.km, industry_alaska.dens.lg.km,  method="ratio")

# Generate rho vs covariate plot
plot(rho_perma_alaska, las=1, main=NULL, legendargs=list(cex=0.8, xpd=TRUE, inset=c(1.01, 0) ))
plot(rho_alaska, las=1, main=NULL, legendargs=list(cex=0.8, xpd=TRUE, inset=c(1.01, 0) ))

#-------------------------------------------------------------------------------
# Create the Poisson point process model
training_contam_data<-contamination_perma_alaska.km[clip=TRUE]
#fit to entire Alaska subset and apply to Alaska industry density
Window(training_contam_data) <- ma_alaska.km
PPM1 <- ppm(training_contam_data, ~offset(rho), covariates=list(rho=as.im(industry_alaska.dens.lg.km)), subset=ma_perma_alaska.km)
PPM2 <- ppm(training_contam_data, ~rho, covariates=list(rho=as.im(industry_alaska.dens.lg.km)), subset=ma_perma_alaska.km)

#-------------------------------------------------------------------------------
#make predictions
pred1 <- predict(PPM1)
pred2 <- predict(PPM2)

count_pred1 <- predict(PPM1, type='count')
count_pred2 <- predict(PPM2, type='count')
count_pred1
count_pred2
contamination_alaska.km$n

# Plot the relationship
plot(effectfun(PPM1, "rho", se.fit=TRUE), xlim=c(-13,-4))
plot(effectfun(PPM2, "rho", se.fit=TRUE),cols=rgb(1,0,0,.2),add=TRUE)
plot(rho_alaska, las=1, main=NULL, legendargs=list(cex=0.8, xpd=TRUE, inset=c(1.01, 0) ), add=TRUE)

plot(pred2)
plot(training_contam_data,add=TRUE)
#-------------------------------------------------------------------------------
#Apply to the pan Arctic permafrost domain 

#fit to permafrost in Alaska but apply to global industry density
training_contam_data<-contamination_perma_alaska.km[clip=TRUE]

#fit to Alaska but apply to global industry density
Window(training_contam_data) <- ma_perma.km
PPM1all <- ppm(training_contam_data, ~offset(rho), covariates=list(rho=as.im(industry_perma.dens.lg.km)), subset=ma_perma_alaska.km)
PPM2all <- ppm(training_contam_data, ~rho, covariates=list(rho=as.im(industry_perma.dens.lg.km)), subset=ma_perma_alaska.km)

pred1all <- predict(PPM1all)
pred2all <- predict(PPM2all)
plot(pred2all)
count_pred1all <- predict(PPM1all, type='count')
count_pred2all <- predict(PPM2all, type='count')
count_pred1all
count_pred2all




