# only if load external data
library(sf)
library(maptools)
library(raster)
library(rgeos)
library(geosphere)
library(rgdal)
library(spatstat)
library(ncdf4)
library(RColorBrewer)
library(oce)
library(maps)

dirname(rstudioapi::getActiveDocumentContext()$path)

s  <- st_read("PerProb_ConDis_glob_buffer.shp")
s_p = st_transform(s, CRS("+init=epsg:3575"))
ma  <- as.owin(s_p)
ma_perma <- ma

s_alaska  <- st_read("Alaska_4326_cut_border.shp")
s_p = st_transform(s_alaska, CRS("+init=epsg:3575"))
ma  <- as.owin(s_p)
ma_alaska <- ma
s_p2 = st_transform(s_alaska, CRS("+init=epsg:5936"))
ma2  <- as.owin(s_p2)
ma_alaska2 <- ma2

s_perma  <- st_read("PerProb_ConDis_Alaska_buffer.shp")
s_p = st_transform(s_perma, CRS("+init=epsg:3575"))
ma  <- as.owin(s_p)
ma_perma_alaska <- ma
s_p2 = st_transform(s_perma, CRS("+init=epsg:5936"))
ma2  <- as.owin(s_p2)
ma_perma_alaska2 <- ma2

# Load a contamination.shp point feature shapefile
s  <- st_read("ContamSites_Indus_only.shp")
s_p = st_transform(s, 3575)
contamination  <- as.ppp(s_p)
marks(contamination)  <- NULL
contamination_alaska <- contamination
Window(contamination_alaska) <- ma_alaska

s_p = st_transform(s, 5936)
contamination2  <- as.ppp(s_p)
marks(contamination2)  <- NULL
contamination_alaska2 <- contamination2
Window(contamination_alaska2) <- ma_alaska2

s_contam  <- st_read("ContamSites_Indus_only_perma.shp")
s_p = st_transform(s_contam, 3575)
contamination  <- as.ppp(s_p)
marks(contamination)  <- NULL
contamination_perma_alaska <- contamination
Window(contamination_perma_alaska) <- ma_perma_alaska

s_p2 = st_transform(s_contam, 5936)
contamination2  <- as.ppp(s_p2)
marks(contamination2)  <- NULL
contamination_perma_alaska2 <- contamination2
Window(contamination_perma_alaska2) <- ma_perma_alaska2

# Load a industry.shp point feature shapefile
s_ind  <- st_read("bigindustry_ipcc_points_final4326_all.shp")
s_p = st_transform(s_ind, 3575)
industry  <- as.ppp(s_p)
marks(industry) <- NULL
industry_alaska <- industry
Window(industry_alaska) <- ma_alaska

s_p2 = st_transform(s_ind, 5936)
industry2  <- as.ppp(s_p2)
marks(industry2) <- NULL
industry_alaska2 <- industry2
Window(industry_alaska2) <- ma_alaska2

# Load a industry.shp point feature shapefile
s  <- st_read("bigindustry_ipcc_points_final4326_perma.shp")
s_p = st_transform(s, 3575)
industry_perma  <- as.ppp(s_p)
marks(industry_perma) <- NULL
industry_perma <- industry_perma 
industry_perma_alaska <- industry_perma 
Window(industry_perma) <- ma_perma
Window(industry_perma_alaska) <- ma_perma_alaska

plot(contamination_alaska, main=NULL, cols=rgb(0,0,0,.2), pch=20)
plot(industry_alaska, main=NULL, cols=rgb(1,0,0,.2), pch=20, add = TRUE)

plot(industry_perma_alaska, main=NULL, cols=rgb(1,0,0,.2), pch=20)
plot(contamination_perma_alaska, main=NULL, cols=rgb(0,0,0,.2), pch=20, add = TRUE)
#-------------------------------------------------------------------------------
#scale everything from meter to km
ma_alaska.km <-  rescale(ma_alaska, 1000, "km") 
ma_perma.km <-  rescale(ma_perma, 1000, "km") 
ma_perma_alaska.km <-  rescale(ma_perma_alaska, 1000, "km") 

contamination_alaska.km <- rescale(contamination_alaska, 1000, "km")
contamination_perma_alaska.km <- rescale(contamination_perma_alaska, 1000, "km")

industry_perma.km <- rescale(industry_perma, 1000, "km")
industry_alaska.km <- rescale(industry_alaska, 1000, "km")
industry_perma_alaska.km <- rescale(industry_perma_alaska, 1000, "km")

# build kernel density raster from points with 50km band width (sigma =50)
band_width <- 50
industry_perma.dens.km <- density(industry_perma.km, sigma=band_width) # Using a specified bandwidth an 10km resolution
industry_perma_alaska.dens.km <- density(industry_perma_alaska.km, sigma=band_width)
industry_alaska.dens.km <- density(industry_alaska.km, sigma=band_width) 

industry_perma.dist.km <- distmap(industry_perma.km)
industry_perma_alaska.dist.km <- distmap(industry_perma_alaska.km)
industry_alaska.dist.km <- distmap(industry_alaska.km)

industry_perma_alaska.dist_gauss.km <- exp(- 0.5*industry_perma_alaska.dist.km^2/band_width^2)
industry_perma.dist_gauss.km <- exp(- 0.5*industry_perma.dist.km^2/band_width^2)
industry_alaska.dist_gauss.km <- exp(- 0.5*industry_alaska.dist.km^2/band_width^2)

hist(industry_perma_alaska.dens.km, main=NULL, las=1) #histogram of the industry raster data
industry_perma_alaska.dens.lg.km <- log(industry_perma_alaska.dens.km) #transform skewed industry distribution to log distribution
industry_perma.dens.lg.km <- log(industry_perma.dens.km) #transform skewed industry distribution to log distribution
industry_alaska.dens.lg.km <- log(industry_alaska.dens.km) #transform skewed industry distribution to log distribution
hist(industry_perma.dens.lg.km, main=NULL, las=1) # new histogram

industry_perma.dens.lg.km[industry_perma.dens.lg.km=="-Inf"]=NaN
industry_perma_alaska.dens.lg.km[industry_perma_alaska.dens.lg.km=="-Inf"]=NaN
industry_alaska.dens.lg.km[industry_alaska.dens.lg.km=="-Inf"]=NaN

#-------------------------------------------------------------------------------
#A point process intensity is estimated following the raster density map as covariate.
# Compute rho using the ratio method
rho_perma_alaska <- rhohat(contamination_perma_alaska.km, industry_perma_alaska.dens.lg.km,  method="ratio")
rho_alaska <- rhohat(contamination_alaska.km, industry_alaska.dens.lg.km,  method="ratio")

# Generate rho vs covariate plot
plot(rho_perma_alaska, las=1, main=NULL, legendargs=list(cex=0.8, xpd=TRUE, inset=c(1.01, 0) ))
plot(rho_alaska, las=1, main=NULL, legendargs=list(cex=0.8, xpd=TRUE, inset=c(1.01, 0) ))

#-------------------------------------------------------------------------------
# Create the Poisson point process model
training_contam_data<-contamination_perma_alaska.km[clip=TRUE]
training_contam_data2<-contamination_perma_alaska2[clip=TRUE]

#fit to entire Alaska subset and apply to Alaska industry density
Window(training_contam_data) <- ma_alaska.km
Window(training_contam_data2) <- ma_alaska2

PPM1 <- ppm(training_contam_data, ~offset(rho), covariates=list(rho=as.im(industry_alaska.dens.lg.km)), subset=ma_perma_alaska.km)
PPM2 <- ppm(training_contam_data, ~rho, covariates=list(rho=as.im(industry_alaska.dens.lg.km)), subset=ma_perma_alaska.km)

#-------------------------------------------------------------------------------
#make predictions
pred1 <- predict(PPM1)
pred2 <- predict(PPM2)

count_pred1 <- predict(PPM1, type='count')
count_pred2 <- predict(PPM2, type='count')
count_pred1
count_pred2
contamination_alaska.km$n

# Plot the relationship
#png(file="ppm_models2.png",width=600, height=400)
par(oma=c(0,1,0,0))
plot(effectfun(PPM1, "rho", se.fit=TRUE), xlim=c(-13,-4), col="#69b3a2",xlab=expression(paste("log(", rho, ")")),cex.lab=1.1,cex.axis=1.05,main=NULL,legend=FALSE,lwd=2.5)
plot(effectfun(PPM2, "rho", se.fit=TRUE), col="#004e89",lwd=2.5,add=TRUE)
plot(rho_alaska, las=1, main=NULL,lwd=2.5, add=TRUE)
grid (NULL,NULL, lty = 2, col = "gray") 
legend(-13.2, 0.0465, legend=c(expression(paste("Fitted PPM ( log ", lambda, "(",rho,") = ",psi," + log(",rho,") )")),expression(paste("Fitted PPM ( log ", lambda, "(",rho,") = ",psi," + ", phi,"*log(",rho,") )")),"Observed intensity"),
       col=c("#69b3a2", "#004e89","black"), lty=1,lwd=2.5, cex=1.05)
#dev.off()

#===============================================================================
#                             Plot maps
#===============================================================================

pred2.m <- rescale(pred2,1/1000,"m")
pred2.m.ras <- raster(pred2.m)
crs(pred2.m.ras) <- CRS("+init=epsg:3575")
writeRaster(pred2.m.ras, filename='Pred2m.tif', format="GTiff", overwrite=TRUE)


pred2_5936 <- projectRaster(pred2.m.ras,crs = CRS("+init=epsg:5936"))

#Color palettes
pal <- brewer.pal(9, "YlOrRd")
pal2 <- rev(brewer.pal(9, "RdBu"))

#Alaska Plot
#png(file="Alaska2.png",width=480, height=500)
data("wrld_simpl", package = "maptools")                                                                            
wm <- crop(wrld_simpl, extent(-180, 180, 30, 90)) 
wm <- spTransform(wm, CRSobj = CRS("+init=epsg:5936"))
par(oma=c(0.5,0.5,0.5,0.5))
par(mar=c(0.5,0.5,0.5,1))
plot(log(pred2_5936), col = pal2,xaxt='n',yaxt='n', xlim=c(-500541, 2985541), ylim=c(-2052684, -20000))
plot(wm, col='grey', add = TRUE)
plot(log(pred2_5936), col = pal2,xaxt='n',yaxt='n', add=TRUE)
plot(industry_alaska2,cols=rgb(0,0,0,.2),pch=20,add=TRUE)
plot(contamination_alaska2,cols=rgb(1,1,0,.2),pch=20,add=TRUE)
plot(ma_alaska2,add=TRUE)
grid(NULL,NULL, lty = 2, col = "black") 
legend(2585541, -600000, legend=c("Industrial sites", "Contaminated sites"), pch = 20,
       col=c(rgb(0,0,0,.2), rgb(1,1,0,.2)), bg='grey')

#dev.off()
#-------------------------------------------------------------------------------
#Apply to the pan Arctic permafrost domain 

#fit to permafrost in Alaska but apply to global industry density
training_contam_data<-contamination_perma_alaska.km[clip=TRUE]

#fit to Alaska but apply to global industry density
Window(training_contam_data) <- ma_perma.km
PPM1all <- ppm(training_contam_data, ~offset(rho), covariates=list(rho=as.im(industry_perma.dens.lg.km)), subset=ma_perma_alaska.km)
PPM2all <- ppm(training_contam_data, ~rho, covariates=list(rho=as.im(industry_perma.dens.lg.km)), subset=ma_perma_alaska.km)

pred1all <- predict(PPM1all)
pred2all <- predict(PPM2all)

pred2all.m <- rescale(pred2all,1/1000,"m")  
pred2all.m.ras <- raster(pred2all.m)
crs(pred2all.m.ras) <- CRS("+init=epsg:3575")
#writeRaster(pred2all.m.ras, filename='/home/aoehme/Documents/Python/Industry/RScript_Moritz_Neu2/Pred2allm.tif', format="GTiff", overwrite=TRUE)

#png(file="pred2all.png",width=550, height=430)
par(oma=c(0.25,0.25,0.25,0.25))
par(mar=c(0.25,0.25,0.25,1))
plot(pred2all, main=NULL, col = pal2,xaxt='n',yaxt='n',pad=0.25)
plot(ma_perma.km,add=TRUE)
#dev.off()


data("wrld_simpl", package = "maptools")                                                                            
wm <- crop(wrld_simpl, extent(-180, 180, 30, 90)) 
wm <- spTransform(wm, CRSobj = CRS("+init=epsg:3575"))
plot(log(pred2all.m.ras), main=NULL, col = pal2,xaxt='n',yaxt='n',pad=0.25, xlim=c(-3857336, 3816403), ylim=c(-3163416, 3681295))
plot(wm, col='grey', add = TRUE)
plot(log(pred2all.m.ras), main=NULL, col = pal2,xaxt='n',yaxt='n',pad=0.25, add=TRUE)
#plot(wm, xlim=c(-3857336, 3816403), ylim=c(-3163416, 3681295), add=TRUE)

count_pred1all <- predict(PPM1all, type='count')
count_pred2all <- predict(PPM2all, type='count')
count_pred1all
count_pred2all




